@@ -3,12 +3,13 @@
 from abc import ABCMeta, abstractmethod
 import logging
 from typing import Union, Dict, Any, Tuple
-from copy import copy
 
 import pandas as pd
 import numpy as np
 import xarray as xr
 
+from .dataset import _get_dataset
+
 
 logger = logging.getLogger(__name__)
 
@@ -48,7 +49,11 @@ class GordoBaseDataset(metaclass=ABCMeta):
             )
         # Update dict with the class
         params = self._params
-        params["type"] = self.__class__.__name__
+        params_type = ""
+        if hasattr(self, '__module__'):
+            params_type = self.__module__ + "."
+        params_type += self.__class__.__name__
+        params["type"] = params_type
         for key, value in params.items():
             if hasattr(value, "to_dict"):
                 params[key] = value.to_dict()
@@ -59,18 +64,7 @@ class GordoBaseDataset(metaclass=ABCMeta):
         """
         Construct the dataset using a config from :func:`~GordoBaseDataset.to_dict`
         """
-        from gordo_dataset import datasets
-
-        config = copy(config)
-        Dataset = getattr(datasets, config.pop("type", "TimeSeriesDataset"))
-        if Dataset is None:
-            raise TypeError(f"No dataset of type '{config['type']}'")
-
-        # TODO: Here for compatibility, but @compate should take care of it, remove later
-        if "tags" in config:
-            config["tag_list"] = config.pop("tags")
-        config.setdefault("target_tag_list", config["tag_list"])
-        return Dataset(**config)
+        return _get_dataset(config)
 
     def get_metadata(self):
         """
